@@ -1,3 +1,4 @@
+from datetime import *
 import click
 import os
 import requests
@@ -83,15 +84,14 @@ def run():
 # Creating command
 @run.command(name='run')
 @click.argument("testrun_id")
-@click.argument("git_pass", required=False)
-def run(testrun_id,git_pass):
-    """If this command is run with testrun id as an argument, aitest CLI will create new test for you with same configuration of provided testrun id.If you used git url for creating test then enter git password as  second argument .
-
-
+@click.option('--wait_time','-w', default=30, required=False)
+@click.option('--git_pass','-p', required=False)
+def run(testrun_id, git_pass, wait_time):
+    """If this command is run with testrun id as an argument, aitest CLI will create new test for you with same configuration of provided testrun id.Enter git password with -p only if you used git url of the automation code for creating the test otherwise no need to enter git password.
+       Enter the waiting time in minutes with -w as an argument, To wait for looking the testrun status.\n
        To re-run the test, you can run below command:\n
-       aitest run [testrun id] [git password]
+       aitest run [testrun id] -p [git password] -w [wait_time]
     """    
-
     try: 
         if os.environ["USER_ID"] and os.environ["CLIENT_ID"] and os.environ["CLIENT_SECRET_ID"]:
             user_id = os.environ["USER_ID"]
@@ -109,7 +109,6 @@ def run(testrun_id,git_pass):
         click.echo('\n"error" : "Please add your valid USER_ID, CLIENT_ID and CLIENT_SECRET_ID in configure file."\n')
         exit()
 
-
     str_to_encode = client_id + ":" + client_secret_id
 
     encoded_str = base64.b64encode(str_to_encode.encode('utf-8'))
@@ -128,12 +127,13 @@ def run(testrun_id,git_pass):
     if token.status_code==400:
         click.echo('\n"error" : "Please add your valid Client ID and Client Secret ID ."\n')
         exit()
+
+        
     else:
         token_data = token.json()
 
     access_token=token_data["access_token"]
   
-
     headers = {"Authorization": f"Bearer {access_token}", "aiTest-User-Identifier":user_id}
 
     base_url = "https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun/load_test"
@@ -141,18 +141,40 @@ def run(testrun_id,git_pass):
     dd = {"testrun_id":testrun_id, "git_password":git_pass}
     
     payload=json.dumps(dd)
+   
 
     res2 =requests.post(base_url,data=payload,headers=headers)
     if res2.status_code==401:
         click.echo('\n"error" : "Please add your valid User ID."\n')
         exit()
     if res2.status_code==200:
-        res_body=res2.json()
-        
+        res_body=res2.json() 
         test_data=json.loads(res_body['body'])
-        click.echo(f"\nTest created successfully\nTest Name : {test_data['load_test_details']['testrun_name']}\nTest Run ID : {test_data['load_test_details']['testrun_id']}\n")
+        click.echo(f"\nTest created successfully\nTest Name : {test_data['load_test_details']['testrun_name']}\nTestrun ID : {test_data['load_test_details']['testrun_id']}\n")
+        click.echo("Testrun is in progress, result will be displayed once it get completed.")
+        new_time = datetime.now() +timedelta(minutes=int(wait_time))
+        test_status=""
+        while test_status!="completed":
+            if (new_time.strftime("%H:%M:%S"))==(datetime.now().strftime("%H:%M:%S")):
+                click.echo(f"The request is timed out. The testrun is still in progress. To see the status of the testrun, please run command : [ aitest status {test_data['load_test_details']['testrun_id']} ].")
+                exit()
+            base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
+            status_res =requests.get(base_url,headers=headers)
+            status_test_data=status_res.json()
+            body=json.loads(status_test_data['body'])
+            test_status = body['testrun_status'] 
+            if test_status=="completed":
+                testrun_status_details=body['testrun_status_details']
+                table = PrettyTable(["browser_name", "browser_version","test run result id", "status", "time taken"])
+                click.echo(f"\ntest status : {test_status}\n")
+                for i in testrun_status_details:
+                    table.add_row([i['browser_name'],i['browser_version'],i['testrun_result_id'],i['testrun_result_status'],i['time_taken']])
+                click.echo(table)            
+        return 1
     else:
         click.echo(res2.json())
+        return 0
+
 # Command Group 
 @click.group(name='status')
 def status():
@@ -230,4 +252,5 @@ def status(testrun_id):
         table.add_row([i['browser_name'],i['browser_version'],i['testrun_result_id'],i['testrun_result_status'],i['time_taken']])
         # click.echo(f"   {i['browser_name']}-{i['browser_version']}    test run result id: {i['testrun_result_id']}   status: {i['testrun_result_status']}   time taken: {i['time_taken']} secs", )
    
-    click.echo(table)
\ No newline at end of file
+    click.echo(table)
+    
\ No newline at end of file
